@@ -2,6 +2,8 @@ from .primitive import Primitive
 from .rectangle import Rectangle
 from .line import Line
 from .polygon import Polygon
-from .spline import Spline
+from .spline import Spline, SplineType
+from .splinegon import Splinegon
 from .group import Group
-from .glyph import Glyph
\ No newline at end of file
+from .glyph import Glyph
+from .circle import Circle
\ No newline at end of file
