@@ -7,8 +7,9 @@ import sys
 
 
 class Glyph(Primitive):
-    def __init__(self, point, type):
-        super().__init__()
+    def __init__(self, point, type, prototype=None):
+        super().__init__(prototype=prototype)
+
         self.x = point[0]
         self.y = point[1]
         self.type = type
