@@ -5,8 +5,8 @@ import xml.etree.ElementTree as ET
 class Group(Primitive):
     Elements = []
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, prototype=None):
+        super().__init__(prototype=prototype)
         self.clear()
 
     def clear(self):
