@@ -1,12 +1,12 @@
-from ipey.primitive import Line
+from ipey.primitive.line import Line
 
 import xml.etree.ElementTree as ET
 
 
 
 class Polygon(Line):
-    def __init__(self, points):
-        super().__init__(points)
+    def __init__(self, points, prototype=None):
+        super().__init__(points, prototype=prototype)
 
     def draw(self):
         elem = ET.Element('path')
