@@ -10,8 +10,8 @@ class SplineType(Enum):
     SPIRO = 2
 
 class Spline(Primitive):
-    def __init__(self, points, splineType = SplineType.BSPLINE):
-        super().__init__()
+    def __init__(self, points, splineType = SplineType.BSPLINE, prototype = None):
+        super().__init__(prototype=prototype)
         self.points = points
         self.splineType = splineType
 
